# Welcome to PyArchery Documents

***Revolutionizing Data Management: The Transformative Potential of a Novel Framework for Semi-Structured Documents***

## Getting Started

* [Tutorial 1 - Getting Started](tutorial_1.md)
* [Tutorial 2 - Data extraction with a complex semi-structured layout](tutorial_2.md)

## How it works

* Please find detailed explanations on how PyArchery works and its unique features [here](https://romualdrousseau.github.io/Archery/)
